@@ -267,7 +267,7 @@ def copy(src, dest=False, **kwargs):
             return
 
     _copy_files_from_array(copy_list)
-    print(f"copy_list: {copy_list}")
+    # print(f"copy_list: {copy_list}")
 
 
 def _copy_files_from_array(files):
